==> gedit-2.1.5.tar.bz2: gedit-2.1.5/src/gedit-plugin.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * gedit-plugin.h
 * This file is part of gedit
 *
 * Copyright (C) 2002 Paolo Maggi 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, 
 * Boston, MA 02111-1307, USA. 
 */
 
/*
 * Modified by the gedit Team, 2002. See the AUTHORS file for a 
 * list of people on the gedit Team.  
 * See the ChangeLog files for a list of changes. 
 */

#ifndef __GEDIT_PLUGIN_H__
#define __GEDIT_PLUGIN_H__

#include <glib.h>
#include <gmodule.h>
#include "gedit2.h"

typedef enum
{
	PLUGIN_OK,
	PLUGIN_ERROR,
	PLUGIN_DEAD
} GeditPluginState;

typedef struct _GeditPlugin GeditPlugin;

struct _GeditPlugin
{
	gchar	*file;
	
	gchar	*location;
	GModule	*handle;

	/* The following fields are compulsory */
	gchar	*name;
	gchar	*desc;
	gchar	*author;
	gchar   *copyright;
	
	/* The following fields are compulsory */
	GeditPluginState	(*init) 	(GeditPlugin *p);
	GeditPluginState	(*activate)	(GeditPlugin *p);
	GeditPluginState	(*deactivate)	(GeditPlugin *p);

	/* The following fields are optional */
	GeditPluginState	(*configure)	(GeditPlugin *p, GtkWidget *parent);
	GeditPluginState	(*update_ui)	(GeditPlugin *p, BonoboWindow *w);
	GeditPluginState	(*destroy)	(GeditPlugin *p);

	/* Eventually filled in by the plugin */
	gpointer	private_data;
};	
	
gchar* gedit_plugin_locate_program  (const gchar *program_name, 
				     const gchar *plugin_name, 
				     GtkWindow *parent);

#endif  /* __GEDIT_PLUGIN_H__ */

==> gedit2-1.109.1.tar.bz2: gedit2-1.109.1/src/gedit-plugin.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * gedit-document.h
 * This file is part of gedit
 *
 * Copyright (C) 2002 Paolo Maggi 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, 
 * Boston, MA 02111-1307, USA. 
 */
 
/*
 * Modified by the gedit Team, 2002. See the AUTHORS file for a 
 * list of people on the gedit Team.  
 * See the ChangeLog files for a list of changes. 
 */

#ifndef __GEDIT_PLUGIN_H__
#define __GEDIT_PLUGIN_H__

#include <glib.h>
#include <gmodule.h>
#include "gedit2.h"

typedef enum
{
	PLUGIN_OK,
	PLUGIN_ERROR,
	PLUGIN_DEAD
} GeditPluginState;

typedef struct _GeditPlugin GeditPlugin;

struct _GeditPlugin
{
	gchar	*file;
	GModule	*handle;

	/* The following fields are compulsory */
	gchar	*name;
	gchar	*desc;
	gchar	*author;
	gchar   *copyright;
	
	/* The following fields are compulsory */
	GeditPluginState	(*init) 	(GeditPlugin *);
	GeditPluginState	(*activate)	(GeditPlugin *);
	GeditPluginState	(*deactivate)	(GeditPlugin *);

	/* The following fields are optional */
	GeditPluginState	(*configure)	(GeditPlugin *, GtkWidget *parent);
	GeditPluginState	(*save_settings)(GeditPlugin *);
	GeditPluginState	(*update_ui)	(GeditPlugin *);
	GeditPluginState	(*destroy)	(GeditPlugin *);

	/* Eventually filled in by the plugin */
	gpointer	private_data;
};	
	

#endif  /* __GEDIT_PLUGIN_H__ */
